@@ -15,7 +15,10 @@ importAQE <- function(site = "yk13", year = 2018, data_type = "hourly",
                     data_type, "_AQE_", year, ".rds")
     
     
-    aq_data <- map_df(files, readSummaryData, data_type = data_type, to_narrow = to_narrow)
+    aq_data <- map_df(files, readSummaryData, 
+                      data_type = data_type, 
+                      to_narrow = to_narrow,
+                      hc = FALSE)
     
     # add meta data?
     if (meta) {
