@@ -18,13 +18,13 @@
 ##' @param mydata A data frame with a \code{date} field and at least one numeric
 ##'   \code{pollutant} field to analyse.
 ##' @param pollutant Name of variable to process. Mandatory.
-##' @param critereon Condition to select run lengths e.g. \code{">"} with select
+##' @param criterion Condition to select run lengths e.g. \code{">"} with select
 ##'   data more than \code{threshold}.
 ##' @param run.len Run length for extracting contiguous values of
 ##'   \code{pollutant} above the \code{threshold} value.
 ##' @param threshold The threshold value for \code{pollutant} above which data
 ##'   should be extracted.
-##' @param result A new column \code{critereon} is returned with string to
+##' @param result A new column \code{criterion} is returned with string to
 ##'   identity whether condition was met.
 ##' @export
 ##' @return Returns a data frame that meets the chosen criteria. See examples
@@ -41,10 +41,10 @@
 ##' ## make a polar plot of those conditions...shows that those
 ##' ## conditions are dominated by low wind speeds, not
 ##' ## in-canyon recirculation
-##' \dontrun{polarPlot(mydata, pollutant = "nox", type = "criteron")}
+##' \dontrun{polarPlot(mydata, pollutant = "nox", type = "criterion")}
 ##' 
 selectRunning <- function(mydata, pollutant = "nox", 
-                          critereon = ">",
+                          criterion = ">",
                           run.len = 5, threshold = 500,
                           result = c("yes", "no")) {
 
@@ -58,7 +58,7 @@ selectRunning <- function(mydata, pollutant = "nox",
   thedata <- checkPrep(mydata, vars, type = "default", remove.calm = FALSE)
 
   x <- thedata[[pollutant]]
-  my_formula <- paste("x", critereon, threshold)
+  my_formula <- paste("x", criterion, threshold)
   rle.seq <- rle(eval(str2lang(my_formula)))
   cumsum.seq <- cumsum(rle.seq$lengths)
   myruns <- which(rle.seq$values == 1 & rle.seq$lengths >= run.len)
@@ -73,12 +73,12 @@ selectRunning <- function(mydata, pollutant = "nox",
     ids <- lapply(1:nrow(res), function(x) seq(res[x, 1], res[x, 2]))
     ids <- do.call(c, ids)
     
-    mydata$criteron <- result[2]
-    mydata$criteron[ids] <- result[1]
+    mydata$criterion <- result[2]
+    mydata$criterion[ids] <- result[1]
     return(mydata)
   } else {
     
-    mydata$criteron <- result[2]
+    mydata$criterion <- result[2]
     return(mydata)
     
   }
