@@ -280,7 +280,8 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
 
     ## if interval specified, then use it
     if (!is.na(interval)) {
-      mydata <- group_by(mydata, UQS(syms(type))) %>%
+      mydata <- mydata %>% 
+        group_by(across(type)) %>%
         do(date.pad2(., type = type, interval = interval))
 
       ## make sure missing types are inserted
@@ -448,7 +449,8 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
       
       if (statistic == "mean") { ## faster for some reason?
         
-        avmet <- group_by(mydata, UQS(syms(vars))) %>%
+        avmet <- mydata %>% 
+          group_by(across(vars)) %>%
           summarise(
             across(everything(),
               ~ if (sum(is.na(.x)) / length(.x) <= 1 - data.thresh) {
@@ -459,7 +461,8 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
             )
           )
       } else {
-        avmet <- group_by(mydata, UQS(syms(vars))) %>%
+        avmet <- mydata %>% 
+          group_by(across(vars)) %>%
           summarise(
             across(everything(),
               ~ if (sum(is.na(.x)) / length(.x) <= 1 - data.thresh) {
@@ -479,7 +482,8 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
       }
 
       avmet <- # select(mydata, -date) %>%
-        group_by(mydata, UQS(syms(vars))) # %>%
+        mydata %>% 
+        group_by(across(vars)) 
 
       # This is much faster for some reason
       if (statistic == "mean") {
@@ -547,7 +551,8 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
   }
 
   ## calculate stats split by type
-  mydata <- group_by(mydata, UQS(syms(type))) %>%
+  mydata <- mydata %>% 
+    group_by(across(type)) %>%
     do(suppressWarnings(calc.mean(., start.date)))
 
   ## don't need default column
